%module position

%{
#include "libharkio3.h"
#include "libharkio3_macros.h"
#define HARKIO_LOG_INITIAL_LEVEL harkio_Log_Error

%}

typedef struct{
    int   id;             /*!< 位置の ID  */
    enum  Coordinate sys; /*!< メンバ coord の座標系 */
    float *coord;         /*!< 座標 */
    char  *path;          /*!< この位置に対応するファイルのパス。TSP録音ファイルなど */
    harkio_Matrix *data;  /*!< この位置に対応する行列データ。伝達関数など */
    int   channelsUse;    /*!< この位置に対応するチャネルセット情報 (numChannels, channels) が有効かどうか。0 は使用しない。 1は使用する。*/
    int   numChannels;    /*!< この位置に対応するチャネルの数 */
    int  *channels;       /*!< この位置に対応するチャネルのリスト */
} harkio_Position;

%extend harkio_Position {
    char *__str__(){
        return harkio_Position_printBuffer($self);
    }
};

harkio_Position* harkio_Position_new(int id, enum Coordinate sys, float *coord, char *path );
void harkio_Position_delete(harkio_Position **pos);
void harkio_Position_print(harkio_Position* pos);

float* harkio_Position_getPosition(harkio_Position* pos);
int harkio_Position_setPosition(harkio_Position* pos, enum Coordinate sys, float *coord);
int  harkio_Position_getSys(harkio_Position *pos);
int harkio_Position_isEqual(harkio_Position *a, harkio_Position *b);
harkio_Position* harkio_Position_copy(harkio_Position *p);
int harkio_Position_Convert(harkio_Position *pos, float *coord, enum Coordinate type);
float harkio_Position_convToRadian(float degree);
float harkio_Position_convToDegree(float radian);
int harkio_Position_getID(harkio_Position* pos);
int  harkio_Positions_getFrame(harkio_Positions *poses);
int harkio_Position_setChannels( harkio_Position* pos , const int *channels, const int numChannels);
int harkio_Position_setNumChannels( harkio_Position* pos , int numChannels );
int harkio_Position_setChannelsUse( harkio_Position* pos , int channels_use );
